## MediaWiki Repository Of Gadgets Useful to Esports (MW ROGUE)

This library is a client for connecting to, and occasionally editing, the Fandom/Gamepedia esports wikis. For general-purpose wiki editing, see `mwcleric`: https://github.com/RheingoldRiver/mwcleric.

## Install/upgrade:

This library can be installed from PyPI:

```
pip install mwrogue
```

For the latest development version, you may wish to pull directly from the repo:

```
pip install -U git+git://github.com/RheingoldRiver/mwrogue
```

## Example code
For example code, see https://github.com/RheingoldRiver/example_wiki_scripts

## API documentation
For Leaguepedia API documentation, see https://lol.fandom.com/wiki/Help:Leaguepedia_API

## Contributing
Feel free to open a pull request or issue!
